==> pycspr-0.8.5.tar.gz: pycspr-0.8.5/README.md <==
casper-client-py
======================================================

Python 3.9+ library for interacting with a CSPR node.


What is casper-client-py ?
------------------------------------------------------

The python client is published as pycspr: **PY**thon **C**a**SP**e**R**.  It's goal is to streamline client side experience of interacting with a casper node.


How To: Install ?
------------------------------------------------------

```
pip install pycspr
```

How To: Query a node  ?
------------------------------------------------------

See [here](how_tos/how_to_query_a_node.py).


How To: Transfer funds between 2 accounts  ?
------------------------------------------------------

See [here](how_tos/how_to_transfer.py).

How To: Delegate funds to a validator  ?
------------------------------------------------------

See [here](how_tos/how_to_delegate.py).

How To: Undelegate funds from a validator  ?
------------------------------------------------------

See [here](how_tos/how_to_undelegate.py).

How To: Stake funds as a validator  ?
------------------------------------------------------

See [here](how_tos/how_to_stake.py).

How To: Unstake funds as a validator ?
------------------------------------------------------

See [here](how_tos/how_to_unstake.py).

How To: Install a smart contract  ?
------------------------------------------------------

See [here](how_tos/how_to_install_a_contract.py).

How To: Invoke a smart contract  ?
------------------------------------------------------

See [here](how_tos/how_to_invoke_a_contract.py).

How To: Run unit tests against an NCTL network ?
------------------------------------------------------

```
cd YOUR_WORKING_DIRECTORY
pipenv shell
pytest ./tests
````

==> pycspr-0.11.0.tar.gz: pycspr-0.11.0/README.md <==
# Casper Python SDK

Python 3.9+ library for interacting with a CSPR node.


What is casper-client-py ?
------------------------------------------------------

The python client is published as pycspr: **PY**thon **C**a**SP**e**R**.  It's goal is to streamline client side experience of interacting with a casper node.


How To: Install ?
------------------------------------------------------

```
pip install pycspr
```

How To: Query a node  ?
------------------------------------------------------

See [here](how_tos/how_to_query_nodes.py).

How To: Transfer funds between 2 accounts  ?
------------------------------------------------------

See [here](how_tos/how_to_transfer.py).

How To: Delegate funds to a validator  ?
------------------------------------------------------

See [here](how_tos/how_to_delegate.py).

How To: Undelegate funds from a validator  ?
------------------------------------------------------

See [here](how_tos/how_to_undelegate.py).

How To: Stake funds as a validator  ?
------------------------------------------------------

See [here](how_tos/how_to_stake.py).

How To: Unstake funds as a validator ?
------------------------------------------------------

See [here](how_tos/how_to_unstake.py).

How To: Install a smart contract  ?
------------------------------------------------------

See [here](how_tos/how_to_install_a_contract.py).

How To: Invoke a smart contract  ?
------------------------------------------------------

See [here](how_tos/how_to_invoke_a_contract.py).

How To: Query a smart contract  ?
------------------------------------------------------

See [here](how_tos/how_to_query_contracts.py).

How To: Hash data  ?
------------------------------------------------------

See [here](how_tos/how_to_hash_data.py).

How To: Create Key Pairs  ?
------------------------------------------------------

See [here](how_tos/how_to_create_key_pairs.py).

How To: Run unit tests against an NCTL network ?
------------------------------------------------------

```
cd YOUR_WORKING_DIRECTORY
pipenv shell
pytest ./tests
````
